@@ -36,7 +36,8 @@ var Interceptor      = require('./interceptor').Interceptor,
     PrismaObserver  = require('../observers/prisma-observer').PrismaObserver,
     OracleObserver  = require('../observers/oracle-observer').OracleObserver,
     CustomMethodObserver = require('../observers/custom-method-observer').CustomMethodObserver,
-    CronObserver = require('../observers/cron-observer').CronObserver;
+    CronObserver = require('../observers/cron-observer').CronObserver,
+    KafkaObserver = require('../observers/kafka-observer').KafkaObserver;
 
 
 var Configuration    = require('./../conf/configure'),
@@ -1048,6 +1049,7 @@ NodeAgent.prototype.startGoAgent = function(opts = {}) {
 
         // 환경 변수 설정
         const newEnv = Object.assign({}, process.env);
+        newEnv['whatap.version'] = NodeUtil.getVersion();
         newEnv['whatap.start'] = Date.now().toString();
         newEnv['node.uptime'] = new Date().toString();
         newEnv['node.version'] = process.version;
@@ -1352,6 +1354,7 @@ NodeAgent.prototype.loadObserves = function() {
     observes.push(PrismaObserver);
     observes.push(OracleObserver);
     observes.push(CronObserver);
+    observes.push(KafkaObserver);
 
     var packageToObserve = {};
     observes.forEach(function(observeObj) {
