@@ -46,11 +46,28 @@ GlobalObserver.prototype.inject = function (mod, moduleName) {
                 }
 
                 if (args[0]) {
-                    const url = new URL(args[0]);
-                    ctx.httpc_url = url.pathname + url.search;
-                    ctx.httpc_host = url.hostname;
-                    ctx.httpc_port = url.port || (url.protocol === 'https:' ? 443 : 80);
-                    ctx.active_httpc_hash = true;
+                    try {
+                        var url;
+                        if (args[0] instanceof URL) {
+                            url = args[0];
+                        } else if (typeof args[0] === 'string') {
+                            url = new URL(args[0]);
+                        } else if (args[0] instanceof Request) {
+                            url = new URL(args[0].url);
+                        } else if (args[0].url) {
+                            // Request-like 객체
+                            url = new URL(args[0].url);
+                        }
+
+                        if (url) {
+                            ctx.httpc_url = url.pathname + url.search;
+                            ctx.httpc_host = url.hostname;
+                            ctx.httpc_port = url.port || (url.protocol === 'https:' ? 443 : 80);
+                            ctx.active_httpc_hash = true;
+                        }
+                    } catch (e) {
+                        // URL 파싱 실패 시 무시
+                    }
                 }
             }
 
