@@ -470,7 +470,56 @@ HttpObserver.prototype.inject = function (mod, moduleName) {
     }
 
     shimmer.wrap(mod, 'request', function (original) {
-        return function wrappedRequest(options, callback) {
+        return function wrappedRequest() {
+            // 인자 정규화: http.request(url[, options][, callback]) 모든 시그니처 지원
+            var args = Array.prototype.slice.call(arguments);
+            var options, callback;
+
+            if (args[0] instanceof URL || typeof args[0] === 'string') {
+                // 첫 번째 인자가 URL인 경우
+                var url;
+                try {
+                    url = typeof args[0] === 'string' ? new URL(args[0]) : args[0];
+                } catch (e) {
+                    // URL 파싱 실패 시 원본 호출
+                    return original.apply(this, arguments);
+                }
+
+                var optionsFromUrl = {
+                    hostname: url.hostname,
+                    port: url.port || (url.protocol === 'https:' ? 443 : 80),
+                    path: url.pathname + url.search,
+                    protocol: url.protocol,
+                };
+
+                if (typeof args[1] === 'object' && args[1] !== null && typeof args[1] !== 'function') {
+                    // http.request(URL, options, callback)
+                    // args[1]의 method, headers 등을 유지하고, URL에서 추출한 hostname, port, path를 덮어씀
+                    options = Object.assign({}, args[1]);
+                    options.hostname = optionsFromUrl.hostname;
+                    options.port = optionsFromUrl.port;
+                    options.path = optionsFromUrl.path;
+                    options.protocol = optionsFromUrl.protocol;
+                    // headers 복사 (참조 문제 방지)
+                    if (args[1].headers) {
+                        options.headers = Object.assign({}, args[1].headers);
+                    }
+                    callback = args[2];
+                } else if (typeof args[1] === 'function') {
+                    // http.request(URL, callback)
+                    options = optionsFromUrl;
+                    callback = args[1];
+                } else {
+                    // http.request(URL)
+                    options = optionsFromUrl;
+                    callback = undefined;
+                }
+            } else {
+                // 기존: http.request(options, callback)
+                options = args[0] || {};
+                callback = args[1];
+            }
+
             var ctx = TraceContextManager.getCurrentContext();
             if (!ctx || (!options.host && !options.hostname)) {
                 return original.apply(this, arguments);
