@@ -90,8 +90,7 @@ var NodeUtil = {
         const major = this.getNodeMajorVersion();
         const minor = this.getNodeMinorVersion();
 
-        // Node.js 18+ 또는 16.7+에서 안정적
-        return major >= 18 || (major === 16 && minor >= 7);
+        return major >= 17 || (major >= 16 && minor >= 7);
     },
 
     // 버전 비교 함수
